package com.example.greetings

import android.graphics.Color
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.View
import android.widget.Button
import android.widget.EditText
import android.widget.TextView
import kotlinx.android.synthetic.main.activity_main.*

class MainActivity : AppCompatActivity() {

    //https://android--code.blogspot.com/2018/01/android-kotlin-button-on-click-listener.html

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        var username: String
        val etName = findViewById<EditText>(R.id.etName)
        /*
            makes connection between code (the Kotlin variable) etName and the
            corresponding item (View) of the interface which has the id of
            etName
            they do not have to be the same but I tend to use the convention
            in which they are the same
        */

        /*
            val versus var  -- val is like "final"
            the username may change values throughout the life of the program
            but once the connection between the variable etName and the View with
            id etName is made, we are not going to change that association
        */

        /*
            When you first introduce a type such as EditText the IDE will complain
            You will need to import that type
            Often you can place the cursor over the squiggly  underlined type and click
            Alt-Enter for the IDE to import for you
        */

        //connect textView variables with TextView Views from the interface
        val tvEnglish = findViewById<TextView>(R.id.tvEnglish)
        val tvFrench = findViewById<TextView>(R.id.tvFrench)
        val tvGerman = findViewById<TextView>(R.id.tvGerman)
        val tvSpanish = findViewById<TextView>(R.id.tvSpanish)

        //connect Button variables with Button Views from the interface
        val btnEnglish = findViewById<Button>(R.id.btnEnglish);
        val btnFrench = findViewById<Button>(R.id.btnFrench);
        val btnGerman = findViewById<Button>(R.id.btnGerman);
        val btnSpanish = findViewById<Button>(R.id.btnSpanish);

        //onClickListener directs the user interface to watch for clicks and respond to the accordingly

        // very explicit version -- establishing an on-click listener requires one to say what
        // will happen when the View -- in this case a button -- is clicked
        // one must override the onClick method which has an argument of a view (the thing clicked)
        btnEnglish.setOnClickListener(object: View.OnClickListener {
            override fun onClick(v: View?) {
                username = etName.text.toString()    //get the text from the EditText convert to a string & assign to username
                tvEnglish.text = "Hello  $username"  // display greeting
                v?.setBackgroundColor(Color.MAGENTA)  // change the color of the view (button)
                v?.isClickable=false
            }
        })
        /*
            The question mark after the type View is related to whether the variable/argument v
            can be null.  The questionmark says it can be -- in other words it is "nullable"

            The question mark in the method v?.setBackgroundColor says to perform the method if
            the object is not null
        */


        /*
            this next version has more implied -- note the absence of the keyword "override" and "fun"
            as well as the function name "onClick"
            there is still a function -- there has to be -- but it is more implied
            the arrow notation makes a separation between the argument v and the execution block of the function
            the type of v, which is a View, is also implied
        */
        btnFrench.setOnClickListener({
                v->
            username = etName.text.toString()
            tvFrench.text = "Bonjour  $username"
            v.setBackgroundColor(Color.rgb(255, 204, 153))
            v.isClickable =false
        })

        // this version is yet even more implied
        // now the argument is implied and if we want to use the argument (to change the button's color)
        // we utilize the keyword "it"
        btnGerman.setOnClickListener{
            username = etName.text.toString()
            tvGerman.text = "Hallo  $username"
            it.setBackgroundColor(Color.argb(128,255, 0, 0))
            it.isClickable=false
        }

        // ***************************************************
        btnSpanish.setOnClickListener{
            username = etName.text.toString()
            tvSpanish.text = "Hola  $username"
            it.setBackgroundColor(Color.parseColor("#99CCFF"))
            it.isClickable=false
        }

        etName.addTextChangedListener(object : TextWatcher {
            //sometimes you need to have some methods even if they are empty
            override fun afterTextChanged(s: Editable) {}

            override fun beforeTextChanged(s: CharSequence, start: Int,
                                           count: Int, after: Int) {
            }

            override fun onTextChanged(s: CharSequence, start: Int,
                                       before: Int, count: Int) {
                tvEnglish.setText("--------")
                tvFrench.setText("--------")
                tvGerman.setText("--------")
                tvSpanish.setText("--------")

                btnEnglish.setBackgroundColor(Color.LTGRAY)
                btnFrench.setBackgroundColor(Color.LTGRAY)
                btnGerman.setBackgroundColor(Color.LTGRAY)
                btnSpanish.setBackgroundColor(Color.LTGRAY)

                btnEnglish.isClickable= true
                btnFrench.isClickable= true
                btnGerman.isClickable= true
                btnSpanish.isClickable= true
            }
        })

    } //end onCreate
} //end MainActivity class